include ${TOPDIR}/mk/kernel-vars.mk

ifeq (${ADK_SQUASHFS_31},y)
MKSQFS_BIN:=mksquashfs-3.1
else
MKSQFS_BIN:=mksquashfs
endif
MKSQFS_OPTS:=-noappend -no-progress -all-root -no-sparse -b 65536
# simplify calling mksquashfs
MAKE_SQFS= ${TRACE} "viprinux/mksquashfs: $(strip ${2})"; \
	PATH='${TARGET_PATH}' ${MKSQFS_BIN} $(1) ${BIN_DIR}/$(strip ${2}) ${MKSQFS_OPTS} 1>/dev/null

### feature image template
# Parameters:
# 1: image name
# 2: packages to put into (viprinux-$(1)-base-files comes automatically)
# 3: optional flags:
#	noauto: do not add to FEATURE_IMAGES variable
define FEATURE_IMG_template
$${BIN_DIR}/$(strip $(1)): FORCE
	-rm -rf $$@
	mkdir -p $$@/.scripts
	for package in viprinux-$(strip $(1))-base-files $(2); do \
		for file in $$$$(ls $${BIN_DIR}/packages/$$$${package}* 2>/dev/null); do \
			tar xf $$$$file -C $$@; \
		done; \
	done
	${BASE_DIR}/scripts/get-scm-version >$$@/.scripts/version
	# update the directory's timestamp, since tar apparently changes that
	touch $$@

ifeq ($(filter noauto, $(3)),)
# add to FEATURE_IMAGES
FEATURE_IMAGE_DIRS+=	$${BIN_DIR}/$(strip $(1))
endif
endef

FEATURE_IMAGE_DIRS:=
$(eval $(call FEATURE_IMG_template, wifi, iw hostapd wireless-tools wpa-supplicant aircrack-ng))
$(eval $(call FEATURE_IMG_template, oprofile, libpopt elfutils binutils oprofile valgrind libbfd slang newt perf))
$(eval $(call FEATURE_IMG_template, devel, screen nmap))
$(eval $(call FEATURE_IMG_template, debugger, strace gdb vipriusb))
$(eval $(call FEATURE_IMG_template, initramfs, viprinux-initramfs-init busybox e2fsck-static losetup sqfsinfo-static tune2fs-static u-boot-env-static, noauto))


${BIN_DIR}/initramfs_list: ${BIN_DIR}/initramfs
	-rm -f $</sbin/init
	bash ${LINUX_DIR}/scripts/gen_initramfs_list.sh -u squash -g squash $</ >$@
	$(SED) 's#^CONFIG_INITRAMFS_SOURCE.*#CONFIG_INITRAMFS_SOURCE="$@"#' \
		$(LINUX_DIR)/.config
	echo "CONFIG_INITRAMFS_COMPRESSION_LZMA=y" >> $(LINUX_DIR)/.config

viprinux-modules-install: ${BIN_DIR}/initramfs_list createinitramfs ${VIPRINUX_KERNEL}
	${KERNEL_MAKE_ENV} ${MAKE} ${KERNEL_MAKE_OPTS} INSTALL_MOD_PATH=${TARGET_DIR} DEPMOD=true modules_install

viprinux-kernel-install: viprinux-modules-install
	mkdir -p ${TARGET_DIR}/boot
	cp ${VIPRINUX_KERNEL} $(BIN_DIR)/viprinet-kernel
	cp ${VIPRINUX_KERNEL} ${TARGET_DIR}/boot/viprinet-kernel

create_feature_images: ${TARGET_DIR} ${FEATURE_IMAGE_DIRS} viprinux-kernel-install
	/sbin/depmod -a -b ${TARGET_DIR} ${KERNEL_VERSION}-viprinux
	mkdir -p ${TARGET_DIR}/.scripts
	${BASE_DIR}/scripts/get-scm-version >${TARGET_DIR}/.scripts/version
	$(call MAKE_SQFS, ${TARGET_DIR}, embedded.sqfs) $(MAKE_TRACE)
	$(call MAKE_SQFS, ${BIN_DIR}/wifi, wifi.sqfs)
	cp ${LINUX_DIR}/vmlinux ${BIN_DIR}/oprofile/viprinet-vmlinux
	$(call MAKE_SQFS, ${BIN_DIR}/oprofile, oprofile.sqfs)
	$(call MAKE_SQFS, ${BIN_DIR}/devel, devel.sqfs)
	$(call MAKE_SQFS, ${BIN_DIR}/debugger, debugger.sqfs)

# empty target to force recreation of depending ones
FORCE:
